@@ -240,16 +240,15 @@ def summarize_pae_pdf(df, threshold):
 def write_top(df, threshold):
     
     if threshold == 0:
-        thresholdstr = "all"
+        basename = "Results"
     else:
-        thresholdstr = str(threshold).replace(".", "p")
+        basename = "Results-iptm-above-" + str(threshold).replace(".", "p")
         
-    basename = "iptm-above-"+thresholdstr
     excelname = basename + ".xlsx"
     csvname = basename + ".csv"
     
     with pd.ExcelWriter(excelname) as writer:  
-        df[df['iptm']>threshold].to_excel(writer, sheet_name="iptm-above-"+thresholdstr)
+        df[df['iptm']>threshold].to_excel(writer)
         
     df.to_csv(csvname)
     
